///////////////////////////////////////////////////////////////////////////////////////////////////
// Module   : sx16mod.h
// Function : Declarations of functions in x16 module-level code that are called by the core.
///////////////////////////////////////////////////////////////////////////////////////////////////

// OS-dependent functions, which are basically wrappers for kernel-supplied functions.
#ifndef DEF_SX16MOD_H
#define DEF_SX16MOD_H

#ifdef WIN32
	#define EAGAIN	256
	#define EFAULT  257
	#define ENODEV  258
#else
	#define __int64 long long
#endif //WIN32

#ifdef __cplusplus
extern "C"
{
#endif

void				SX16MOD_sleep				( int milliseconds );
void                SX16MOD_sleepq              ( void *board, int timeout);
unsigned short		SX16MOD_read_io16			( int addr );
void				SX16MOD_write_io16			( int addr, unsigned short data );
unsigned long		SX16MOD_read_mem32			( unsigned long addr );
void				SX16MOD_write_mem32			( unsigned long addr, unsigned long data );
void				SX16MOD_block_read_io16		( int addr, unsigned short *buf, int nwords );
void				SX16MOD_block_write_io16	( int addr, unsigned short *buf, int nwords );
void *				SX16MOD_open_microcode		( int microcode_id, int streamtype, int afmt );
int					SX16MOD_read_microcode		( void *handle, void *databuf, int desired_byte_count );
void				SX16MOD_close_microcode		( void *handle );
unsigned __int64	SX16MOD_time_now			( void );
void				SX16MOD_text_message		( char *txt );
void 				SX16MOD_hex_message			( int digits, int num );
void *				SX16MOD_create_mutex		( void );
void 				SX16MOD_delete_mutex		( void *mutex_object );
int					SX16MOD_acquire_mutex		( void *mutex_object );
void				SX16MOD_acquire_mutex_nonint	( void *mutex_object );
void				SX16MOD_release_mutex		( void *mutex_object );
void                SX16MOD_release_threads     ( void *board);
void *				SX16MOD_malloc				( int size );
void				SX16MOD_free				( void *virt_addr );
void                SX16MOD_do_gettimeofday     ( void *tv);
// do_gettimeofday function
void                SX16MOD_do_gettimeofday_secs( long *tval); 
void                SX16MOD_do_gettimeofday_usecs( long *tval); 
void                SX16MOD_free_dma            ( void *handle, int size, unsigned long *cpu_addr, unsigned long dma_handle );
void                SX16MOD_alloc_dma           ( void *handle, int size, unsigned long **cpu_addr, unsigned long *dma_handle );

int                 SX16MOD_get_hz              ( void );
//Debug
void 				SX16MOD_lpt 				( unsigned char data );
unsigned long 		SX16MOD_get_jiffies 		( void );
void 				SX16MOD_dbg_wr_dword 		( unsigned long);
void 				SX16MOD_dbg_write 			( void *buf, unsigned int chunk );
void                dbgprint                    ( char *fmt, ... );

void  dbgprint3( char *fmt, int arg1,int arg2, int arg3 );
unsigned long       SX16MOD_getphys             (void *virt_addr);
unsigned long       SX16MOD_get_PAGESIZE        ( void );

// call back function for sensoray write
unsigned long       SX16MOD_write_core          ( void *board, const char *buffer, unsigned long nbytes, int no_block);

//other os specific functions(string.h)
    
int                 SX16MOD_memcmp              ( void *s1, void *s2, int size);
void                SX16MOD_memmove             ( char *dst, char *src, int size);

// only included from mod file
#ifdef MODULE_FILE_BUILD

#define STATUS_CAPTURE 0x0001
#define STATUS_OVERLAY 0x0002



//#endif
#endif

#ifdef __cplusplus
}
#endif

#endif //DEF_SX16MOD_H
